<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * Block for webhook events grid for Koongo order api module
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */

class Nostress_Koongoorderapi_Block_Adminhtml_Webhook_Event_Grid extends Mage_Adminhtml_Block_Widget_Grid
{

    public function __construct()
    {
        parent::__construct();
        $this->setId('koongoorderapiGrid');
        $this->setDefaultSort('entity_id');
        $this->setDefaultDir('asc');
        $this->setSaveParametersInSession(true);
    }

    /**
     * Init customer groups collection
     * @return void
     */
    protected function _prepareCollection()
    {
        $collection = Mage::getModel('koongoorderapi/webhook_event')->getCollection();
        $this->setCollection($collection);
        return parent::_prepareCollection();
    }

    /**
     * Configuration of grid
     */
    protected function _prepareColumns()
    {
        $this->addColumn('id', array(
            'header' => Mage::helper('koongoorderapi')->__('Event ID'),
            'width' => '10px',
            'align'	=> 'center',
            'index' => 'entity_id',
        ));

        $this->addColumn('parent_event_id', array(
            'header' => Mage::helper('koongoorderapi')->__('Parent Event ID'),
            'width' => '10px',
            'align'	=> 'center',
            'index' => 'parent_event_id',
        ));

        $this->addColumn('duplicity_counter', array(
            'header' => Mage::helper('koongoorderapi')->__('Duplicity Counter'),
            'width' => '10px',
            'align'	=> 'center',
            'index' => 'duplicity_counter',
            'type'    => 'options',
          	'options' => array(0,1,2,3,4,5,6)
        ));        
       
        $this->addColumn('webhook_id', array(
            'header' => Mage::helper('koongoorderapi')->__('Webhook ID'),           
            'align'	=> 'center',
            'width' => '10px',
            'index' => 'webhook_id',
        ));

        $this->addColumn('order_id', array(
            'header' => Mage::helper('koongoorderapi')->__('Real Order ID'),           
            'align'	=> 'center', 
            'width' => '15px',           
            'index' => 'order_id',
        ));

        $this->addColumn('topic', array(
            'header' => Mage::helper('koongoorderapi')->__('Topic'),           
            'align'	=> 'center',            
            'index' => 'topic',
            'width' => '100px', 
        ));        

        $this->addColumn('params', array(
            'header' => Mage::helper('koongoorderapi')->__('Params'),           
            'align'	=> 'center',            
            'index' => 'params',
        ));

        $this->addColumn('status', array(
            'header' => Mage::helper('koongoorderapi')->__('Status'),           
            'align'	=> 'center',            
            'index' => 'status',
            'type'    => 'options',
          	'options' =>	Mage::getModel('koongoorderapi/webhook_event')->getStatusesAsIndexedArray()
        ));

        $this->addColumn('message', array(
            'header' => Mage::helper('koongoorderapi')->__('Message'),           
            'align'	=> 'center',            
            'index' => 'message',
        ));

       $this->addColumn('updated_at', array(
        		'header' => Mage::helper('koongoorderapi')->__('Updated At'),
        		'align'		=> 'center',
        		'type'      => 'date_time',
        		'index' => 'updated_at',
        ));
        
        $this->addColumn('created_at', array(
            'header' => Mage::helper('koongoorderapi')->__('Created At'),
        	'align'		=> 'center',
            'type'      => 'date_time',
            'index' => 'created_at',
        ));                       
        return parent::_prepareColumns();
    }

    // public function getRowUrl($row)
    // {
    //     return $this->getUrl('*/*/edit', array('id'=>$row->getId()));
    // }
    
    protected function _prepareMassaction()
    {
        $this->setMassactionIdField('entity_id');
        $this->getMassactionBlock()->setFormFieldName('event');        

        $this->getMassactionBlock()->addItem('run', array(
            'label'=> Mage::helper('koongoorderapi')->__('Run'),
            'url'  => $this->getUrl('*/*/massRun'),
            'confirm' => Mage::helper('koongoorderapi')->__('Are you sure to execute selected events?')
            ));

        $this->getMassactionBlock()->addItem('set_pending', array(
            'label'=> Mage::helper('koongoorderapi')->__('Set status Pending'),
            'url'  => $this->getUrl('*/*/massSetPending'),
            'confirm' => Mage::helper('koongoorderapi')->__('Are you sure to set status Pending to selected events?')
            ));

        $this->getMassactionBlock()->addItem('delete', array(
            'label'=> Mage::helper('koongoorderapi')->__('Delete'),
            'url'  => $this->getUrl('*/*/massDelete'),
            'confirm' => Mage::helper('koongoorderapi')->__('Are you sure?')
                ));
    }

}
