<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * Block for webhooks grid for Koongo order api module
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */

class Nostress_Koongoorderapi_Block_Adminhtml_Webhook_Grid extends Mage_Adminhtml_Block_Widget_Grid
{

    public function __construct()
    {
        parent::__construct();
        $this->setId('koongoorderapiGrid');
        $this->setDefaultSort('entity_id');
        $this->setDefaultDir('asc');
        $this->setSaveParametersInSession(true);
    }

    /**
     * Init customer groups collection
     * @return void
     */
    protected function _prepareCollection()
    {
        $collection = Mage::getModel('koongoorderapi/webhook')->getCollection();
        $this->setCollection($collection);
        return parent::_prepareCollection();
    }

    /**
     * Configuration of grid
     */
    protected function _prepareColumns()
    {
        $this->addColumn('id', array(
            'header' => Mage::helper('koongoorderapi')->__('Webhook ID'),
            'width' => '10px',
            'align'	=> 'center',
            'index' => 'entity_id',
        ));

        $this->addColumn('topic', array(
            'header' => Mage::helper('koongoorderapi')->__('Topic'),           
            'align'	=> 'center',            
            'index' => 'topic',
            'width' => '100px', 
        ));

        $this->addColumn('url', array(
            'header' => Mage::helper('koongoorderapi')->__('Url'),           
            'align'	=> 'center',            
            'index' => 'url'             
        ));

        $this->addColumn('store_id', array(
            'header' => Mage::helper('koongoorderapi')->__('Store ID'),           
            'align'	=> 'center',
            'width' => '10px',
            'index' => 'store_id',
        ));

        $this->addColumn('secret', array(
            'header' => Mage::helper('koongoorderapi')->__('Secret'),           
            'align'	=> 'center',
            'width' => '40px',
            'index' => 'secret',
        ));

        $this->addColumn('updated_at', array(
            'header' => Mage::helper('koongoorderapi')->__('Updated At'),
            'align'		=> 'center',
            'type'      => 'date_time',
            'width' => '40px',
            'index' => 'updated_at',
        ));
    
        $this->addColumn('created_at', array(
            'header' => Mage::helper('koongoorderapi')->__('Created At'),
            'align'		=> 'center',
            'type'      => 'date_time',
            'width' => '40px',
            'index' => 'created_at',
        ));                               
        return parent::_prepareColumns();
    }

    protected function _prepareMassaction()
    {
        $this->setMassactionIdField('entity_id');
        $this->getMassactionBlock()->setFormFieldName('webhook');        

        $this->getMassactionBlock()->addItem('delete', array(
            'label'=> Mage::helper('koongoorderapi')->__('Delete'),
            'url'  => $this->getUrl('*/*/massDelete'),
            'confirm' => Mage::helper('koongoorderapi')->__('Are you sure?')
                ));
    }
}
