<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */ 

class Nostress_Koongoorderapi_Helper_Data extends Mage_Core_Helper_Abstract
{
    //log
    const LOG_FILE = "koongoorder.txt";
    
    //config paths
    const PATH_GENERAL = 'koongo_order_api/general/';
    const PATH_CUSTOMER = 'koongo_order_api/customer/';
	const PATH_HELP = 'koongo_order_api/help/';	

	//config params
    const PARAM_CREATE_CUSTOMER_DURING_IMPORT = 'create_customer_during_import';
    const PARAM_CUSTOMER_GROUP_ID = 'customer_group_id';
    const PARAM_GTIN_ATTRIBUTE = 'gtin_attribute';
    const PARAM_IMPORT_BACKORDERS = 'import_backorders';
    const PARAM_PRESENTATION_URL = 'presentation_website_url';
    const PARAM_SHOW_ORDER_GRID_COLUMNS = 'show_order_grid_columns';
    const PARAM_DEF_SHIPPING_METHOD = 'default_shipping_method';
    const PARAM_SEC_SHIPPING_METHOD = "secondary_shipping_method";
    const PARAM_ORDER_INCREMENT_ID_FORMAT = "order_increment_id_format";
    const PARAM_DEBUG_MODE = "debug_mode";

    const KOONGO_ORDER_COMMAND_STATUS_COMPLETE = "complete";
    const KOONGO_ORDER_COMMAND_STATUS_WARNING = "warning";

    //Channel cache
    const CHANNEL_CACHE_DIR = "ChannelCacheM1";
    const CHANNEL_LOGO_FILE = "logo.png";
    const CHANNEL_DIR = "Channel";
    const MARKETPLACE_FLAGS_DIR = "MarketplaceFlags";

    /**
     * Preparare REST api response body
     *
     * @param String $status Order command status
     * @param String $message 
     * @param Updated data obtained f $data
     * @return void
     */
    public function prepareResponseBody($status, $message, $data, $jsonEncode = true)
    {
        $responseBody = array();
        
        $responseBody["info"] = array();        
        $responseBody["info"]["status"] = $status;
        $responseBody["info"]["message"] = $message;

        if(isset($data))
            $responseBody["data"] = $data;
        
        if($jsonEncode)
            return json_encode($responseBody);
        else 
            return $responseBody;
    }

    public function getChannelLogoUrl($channelCode)
	{
		return $this->getChannelCacheUrl($channelCode).self::CHANNEL_LOGO_FILE;
    }
    
    public function getChannelMarketplaceFlag($marketplaceCode)
    {
        return $this->getGeneralConfig(self::PARAM_PRESENTATION_URL)."media/".self::CHANNEL_DIR."/".self::MARKETPLACE_FLAGS_DIR."/".$marketplaceCode.".png";
    }

    public function getChannelCacheUrl($channelCode)
	{
		return $this->getGeneralConfig(self::PARAM_PRESENTATION_URL)."media/".self::CHANNEL_CACHE_DIR."/".$channelCode."/";		
    }
    
    /**
     * Get available options for some attribute
     *
     * @param String $attributeCode Order attribtue Code
     * @return void
     */
    public function getOrderAttributeOptions($attributeCode, $labelUcFirst = false)
    {
        $collection = Mage::getModel("sales/order")->getCollection()->addFieldToSelect($attributeCode);
        $select = $collection->getSelect();
        $select->distinct();
        $collection->load();
        
        $options = array();
        foreach ($collection as $item) {
            $value = $item->getData($attributeCode);
            if(!empty($value))
            {
                $label = $value;
                if($labelUcFirst)
                    $label = ucfirst(strtolower($label));
                $options[$value] = $label;
            }
        }
        ksort($options);
        return $options;
    }

    /**
     * Get current date time by adjusted time zone
     *
     * @return String
     */
    public function getNow()
    {
        // echo Mage::getModel('core/date')->date('Y-m-d H:i:s'); exit();
        return Mage::getModel('core/date')->date('Y-m-d H:i:s');
    }

    /**
     * Get  date time by adjusted time zone
     *
     * @param String $input E.g. -1 day
     * @return void
     */
    public function getTime($input = null)
    {
        return Mage::getModel('core/date')->date('Y-m-d H:i:s',$input);
    }
    
    /**
     * Return date time for now
     * @param DateTimeFormat $format, DateTime::ATOM =  2005-08-15T15:52:01+00:00, DateTime::ISO8601 = 2005-08-15T15:52:01+0000
     * @param int $timestamp
     * @return string
     */
    public function getDatetimeString($format = DateTime::ATOM,$timestamp = null)
    {
    	if(empty($timestamp))
    		return date($format);
    	else 
    		return date($format,$timestamp);
    	
    }
    
    /**
     * Convert datetime string from orignal format into defined format
     * @param String $datetime
     * @param string $format The format of the outputted date string. See the formatting options below. There are also several predefined date constants that may be used instead, so for example DATE_RSS contains the format string 'D, d M Y H:i:s'.
     * @return string
     */
    public function formatDatetime($datetime = "", $format = DateTime::ATOM)
    {
    	if(!empty($datetime)) {
    	    $datetime = strtotime($datetime);
    	}
    	return $this->getDatetimeString($format, $datetime);
    }

    //*********************** CONFIG - START**********************************

    /**
     * Return store config value for key
     *
     * @param   string $key
     * @return  string
     */
    public function getGeneralConfig ($key, $flag=false,$asArray=false,$storeId = null)
    {
        $path = self::PATH_GENERAL.$key;
        return $this->_getConfig($path, $flag,$asArray,$storeId);
    }

    /**
     * Return store config value for key
     *
     * @param   string $key
     * @return  string
     */
    public function getCustomerConfig ($key, $flag=false,$asArray=false,$storeId = null)
    {
        $path = self::PATH_CUSTOMER.$key;
        return $this->_getConfig($path, $flag,$asArray,$storeId);
    }

    

    public function getConfig($path, $flag=false,$asArray=false,$storeId = null)    
    {
        return $this->_getConfig($path, $flag, $asArray, $storeId);
    }

    protected function _getConfig($path, $flag=false,$asArray=false,$storeId = null)
    {
        $result = null;
        if ($flag)
        	$result = Mage::getStoreConfigFlag($path,$storeId);
	    else
	    	$result = Mage::getStoreConfig($path,$storeId);

        if($asArray)
        	$result = explode(",",$result);
        return $result;
    }
    
    //*********************** LOG *****************************************
    public function log($message)
    {
        Mage::log($message,null,self::LOG_FILE);
    }
}
	 