<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */ 

class Nostress_Koongoorderapi_Helper_Order_Data extends Nostress_Koongoorderapi_Helper_Data
{
    /**
     * Load catalog product from database by product id or product identification attribute
     */
    public function loadCatalogProduct($storeId, $productId, $productIdentificationAttributeCode = null, $productIdentificationAttributeValue = null, $gtinAttribute = null)
    {        
        $product = Mage::getModel('catalog/product');
        
        if(isset($productId))
            $product->setStoreId($storeId)->load($productId);        

        if(!$product->getId())
        {                                    
            //Try to find product
            if(isset($productIdentificationAttributeCode) && isset($productIdentificationAttributeValue))
            {
                $filterAttribute = $productIdentificationAttributeCode;
                if($productIdentificationAttributeCode == "ean" && isset($gtinAttribute))
                    $filterAttribute = $gtinAttribute;
                    
                $productCollection = Mage::getModel('catalog/product')->getCollection()->setStoreId($storeId);
                $productCollection->addAttributeToSelect('*')
                    ->addFieldToFilter($filterAttribute, array('eq' => $productIdentificationAttributeValue));
                $productCollection->load();
                if(count($productCollection->getItems()) > 0)
                    $product = $productCollection->getFirstItem();
            }
        }

        return $product;
    }

    /**
     * Created increment id based on provided params
     *
     * @param string $channelCode Koongo channel code
     * @param string $channelOrderId Koongo channel order id
     * @param string $marketplaceCode Koongo marketplace code
     * @return void
     */
    public function generateUniqueOrderIncrementId($channelCode, $channelOrderId, $marketplaceCode = null)
    {        
        $incrementId = $channelCode."-";
        if(isset($marketplaceCode))
            $incrementId .=  strtolower($marketplaceCode)."-";
        $incrementId .= $channelOrderId;

        $originalIncrementId = $incrementId;
        $index = 1;
        while($this->checkOrderExists($incrementId))
        {
            $incrementId = $originalIncrementId."-".$index;
            $index++;
        }

        return $incrementId;
    }

    /**
     * Check if order exists
     *
     * @param String $incrementId Order increment id
     * @return void
     */
    public function checkOrderExists($incrementId)
    {
        $order = Mage::getModel('sales/order')->loadByIncrementId($incrementId);        
        if($order->getId())
            return true;
        return false;
    }

    /**
     * Check if order has   at least one shipment
     *
     * @param Mage_Sales_Model_Order $order
     * @return boolean
     */
    public function orderHasShipment($order)
    {
        $shipmentCollection = $order->getShipmentsCollection();
        if(!$shipmentCollection || !isset($shipmentCollection))
            return false;

        foreach ($shipmentCollection as $shipment) {
            return true;
        }
        return false;
    }
}
	 