<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * API2 class for order comments (Koongo)
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */
class Nostress_Koongoorderapi_Model_Api2_Order_Cancel_Rest_Admin_V1 extends Nostress_Koongoorderapi_Model_Api2_Order
{
    /**
     * Create product
     *
     * @param array $data
     * @return string
     */
    protected function _create(array $data)
    {     
        $realOrderId = $this->getRequest()->getParam('id');
        $order = $this->_loadOrder($realOrderId);

        if(!isset($data['note']) || empty($data['note']))
            $this->_critical($this->_helper()->__("Missing note in request."), Mage_Api2_Model_Server::HTTP_BAD_REQUEST);

        Mage::register("koongoorderapi_order_canceled_from_kaas", true);        
        if ($order->canCancel()) {
            try {
                $order->cancel();                        
                //remove default comment
                $order->getStatusHistoryCollection(true);
                $this->_addComment($order, array("message" => $data['note']));
                $order->save();                
            } catch (Exception $e) {
                Mage::unregister("koongoorderapi_order_canceled_from_kaas");
                $this->_critical($this->_helper()->__("Order cancelation failed. Reason: %s", $e->getMessage()), Mage_Api2_Model_Server::HTTP_BAD_REQUEST);
            }
        }
        else if(!$this->_helper()->orderHasShipment($order)) //Order is paid but not sent
        {
           $creditMemoId = $this->_prepareCreditMemo($order, $this->_helper()->__("Order canceled by %s", $order->getChannelLabel()));        
        }
        else
            $this->_critical($this->_helper()->__("Order cannot be canceled. Current status is %s",$order->getStatus()), Mage_Api2_Model_Server::HTTP_BAD_REQUEST);
        
        Mage::unregister("koongoorderapi_order_canceled_from_kaas");

        //Order is ready, prepare invoice and return response
        $responseMessage = "";
        $responseStatus = Nostress_Koongoorderapi_Helper_Data::KOONGO_ORDER_COMMAND_STATUS_COMPLETE;

        unset($customer);

        $responseBody = $this->_helper()->prepareResponseBody($responseStatus, $responseMessage, array('id' => $order->getId()));       
        $this->getResponse()->setBody($responseBody);
        return true;
    }
}
