<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * API2 class for find product id (Koongo)
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */
class Nostress_Koongoorderapi_Model_Api2_Order_Findproductid_Rest_Admin_V1 extends Nostress_Koongoorderapi_Model_Api2_Order
{
    /**
     * Create product
     *
     * @param array $data
     * @return string
     */
    protected function _retrieve()
    {        
        $data = $this->getRequest()->getParams();

        if(!isset($data['store_id']) || empty($data['store_id']))
            $this->_critical($this->_helper()->__("Missing store_id in request."), Mage_Api2_Model_Server::HTTP_BAD_REQUEST);

        if(!isset($data['product_identification_attribute_code']) || empty($data['product_identification_attribute_code']))
            $this->_critical($this->_helper()->__("Missing product_identification_attribute_code in request."), Mage_Api2_Model_Server::HTTP_BAD_REQUEST);

        if(!isset($data['product_identification_attribute_value']) || empty($data['product_identification_attribute_value']))
            $this->_critical($this->_helper()->__("Missing product_identification_attribute_value in request."), Mage_Api2_Model_Server::HTTP_BAD_REQUEST);

        $storeId = $data['store_id'];
        $productIdentificationAttributeCode = $data['product_identification_attribute_code'];
        $productIdentificationAttributeValue = $data['product_identification_attribute_value'];
        $gtinAttribute = $this->_getGtinAttribute($storeId);

        try {
            $product = $this->_helper()->loadCatalogProduct($storeId, null, $productIdentificationAttributeCode, $productIdentificationAttributeValue, $gtinAttribute);
        } catch (Exception $e) {
            $this->_critical($this->_helper()->__("Product load failed. Reason: %s", $e->getMessage()), Mage_Api2_Model_Server::HTTP_BAD_REQUEST);
        }      

        $responseMessage = "";
        $responseStatus = Nostress_Koongoorderapi_Helper_Data::KOONGO_ORDER_COMMAND_STATUS_COMPLETE;
        $responseArray = null;
        $productId = null;
        if($product->getId())
        { 
            $productId = $product->getId();
            $responseArray= array('id' => $productId);
        }
        else
        {
            $responseMessage = $this->_helper()->__("Product with %s = %s not found.",$productIdentificationAttributeCode, $productIdentificationAttributeValue);
            $responseStatus = Nostress_Koongoorderapi_Helper_Data::KOONGO_ORDER_COMMAND_STATUS_WARNING;
        }

        $responseBody = $this->_helper()->prepareResponseBody($responseStatus, $responseMessage, $responseArray);       
        $this->getResponse()->setBody($responseBody);
        return true;
    }
}
