<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * API2 class for webhooks (admin)
 *
 * @category   Mage
 * @package    Mage_Sales
 * @author     Magento Core Team <core@magentocommerce.com>
 */
class Nostress_Koongoorderapi_Model_Api2_Webhook extends Mage_Api2_Model_Resource
{
    const API_RESPONSE_STATUS_SUCCESS = "success";        

    /**
     * Current store.
     */
    protected $_store;
    protected $_helper;    
    
    /**
     * Create new webhook
     * @param Array $name Webhook data.
     */
    protected function _createWebhook($data)
    {
        $webhook = Mage::getModel('koongoorderapi/webhook');
        $webhook->setData($data);
        $now = $this->_helper()->getNow();
        $webhook->setCreatedAt($now);
        $webhook->setUpdatedAt($now);
        $webhook->save();
        return $webhook;
    }

    /**
     * Update webhook
     *
     * @param Nostress_Koongoorderapi_Model_Webhook $webhook
     * @param Array $webhookData
     * @return void
     */
    protected function _updateWebhook($webhook, $webhookData)
    {
        foreach ($webhookData as $key => $value) {
            $webhook->setData($key, $value);
        }
        $webhook->save();
        return $webhook;
    }

    /**
     * Prepare webhook data for response
     *
     * @param  Nostress_Koongoorderapi_Model_Webhook $webhook
     * @return Array
     */
    protected function _prepareWebhookDataForResponse($webhook)
    {
        $webhookData = $webhook->getData();
        
        $webhookData = array( 'id'=>$webhook->getId()) + $webhookData;
        unset($webhookData['secret']);
        unset($webhookData['entity_id']); 
        return $webhookData;
    }

    /**
     * Check if webhook item already exists
     *
     * @param Array $webhookData
     * @return Boolean
     */
    protected function _webhookExists($webhookData)
    {
        $collection = Mage::getModel('koongoorderapi/webhook')->getCollection();
        $select = $collection->getSelect();
        $select->where( 'store_id = ?', $webhookData["store_id"])
                ->where( 'topic = ?', $webhookData["topic"])
                ->where( 'url = ?', $webhookData["url"]);
        $collection->load();

        $firstItem = $collection->getFirstItem();
        if(!$firstItem->getId())
            return false;
        return true;        
    }

    protected function _helper()
    {
        if(!isset($this->_helper))
    	    $this->_helper = Mage::helper('koongoorderapi/data');
    	return $this->_helper;
    }
    
    protected function _log($message)
    {
        $this->_helper()->log($message);
    }

    protected function _setStore($store)
    {
        if(is_numeric($store))
            $this->_store = Mage::app()->getStore($store);
        else
            $this->_store = $store;
    }

    protected function _getStore()
    {
        return $this->_store;
    }

    protected function _getStoreId()
    {
        return $this->_getStore()->getStoreId();
    }

    protected function _getWebsiteId()
    {
        return $this->_getStore()->getWebsiteId();
    }

    protected function _getArrayField($index,$array, $default = null)
    {
        if(!is_array($array))
        {
            return $default;
        }
    	if(array_key_exists($index,$array))
    	{
    		return $array[$index];
    	}
    	else
    		return $default;
    }
}
