<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * API2 class for webhooks (Koongo)
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */
class Nostress_Koongoorderapi_Model_Api2_Webhook_Rest_Admin_V1 extends Nostress_Koongoorderapi_Model_Api2_Webhook
{
    /**
     * Create webhook
     *
     * @param array $data
     * @return string
     */
    protected function _create(array $data)
    {
        $validator = $this-> _getDataValidator(self::OPERATION_CREATE);
        
        if (!$validator->isValidData($data)) {
            foreach ($validator->getErrors() as $error) {
                $this->_error($error, Mage_Api2_Model_Server::HTTP_BAD_REQUEST);
            }
            $this->_critical(self::RESOURCE_DATA_PRE_VALIDATION_ERROR);
        } 

        if($this->_webhookExists($data))
            $this->_critical($this->_helper()->__("Webhook with given parameters already exists."), Mage_Api2_Model_Server::HTTP_INTERNAL_ERROR);

        try {
            $webhook = $this->_createWebhook($data);
            if(!$webhook->getId())
                throw new Exception("Missing webhook entity_id");

// should working but after location returns
//            $location = $this->_getLocation( $webhook);
//            return $location;
        } catch (Exception $e) {
            $this->_critical($this->_helper()->__("Webhook creation failed. Reason: %s", $e->getMessage()), Mage_Api2_Model_Server::HTTP_INTERNAL_ERROR);
        }
        
        $webhookData = $this->_prepareWebhookDataForResponse($webhook);
        $responseBody = $this->_helper()->prepareResponseBody(self::API_RESPONSE_STATUS_SUCCESS, "", array('webhook' => $webhookData ));
        $this->getResponse()
            ->setBody($responseBody)
            ->sendResponse();
        exit;
    }

    /**
     * Update webhook by its ID
     *
     * @param array $data
     */
    protected function _update(array $data)
    {
        $validator = $this-> _getDataValidator(self::OPERATION_UPDATE);

        if (!$validator->isValidData($data)) {
            foreach ($validator->getErrors() as $error) {
                $this->_error($error, Mage_Api2_Model_Server::HTTP_BAD_REQUEST);
            }
            $this->_critical(self::RESOURCE_DATA_PRE_VALIDATION_ERROR);
        }

        $webhookId = $this->getRequest()->getParam('id');
        $webhook = Mage::getModel('koongoorderapi/webhook')->load($webhookId);
        if(!$webhook->getId())
            $this->_critical($this->_helper()->__("Can't find webhook with id %s", $webhookId), Mage_Api2_Model_Server::HTTP_INTERNAL_ERROR);
        
        try {
            $webhook = $this->_updateWebhook($webhook, $data);
        } catch (Exception $e) {
            $this->_critical($this->_helper()->__("Webhook update failed. Reason: %s", $e->getMessage()), Mage_Api2_Model_Server::HTTP_INTERNAL_ERROR);
        }

        $webhookData = $this->_prepareWebhookDataForResponse($webhook);
        $responseBody = $this->_helper()->prepareResponseBody(self::API_RESPONSE_STATUS_SUCCESS, "", array('webhook' => $webhookData ));       
        $this->getResponse()
            ->setBody($responseBody)
            ->sendResponse();
        exit;
    }

    /**
     * Delete webhook by its ID
     *
     * @throws Mage_Api2_Exception
     */
    protected function _delete()
    {
        $webhookId = $this->getRequest()->getParam('id');
        $webhook = Mage::getModel('koongoorderapi/webhook')->load($webhookId);
        if(!$webhook->getId())
            $this->_critical($this->_helper()->__("Can't find webhook with id %s", $webhookId), Mage_Api2_Model_Server::HTTP_INTERNAL_ERROR);
        
        try {
            $webhook->delete();
        } catch (Exception $e) {
            $this->_critical($this->_helper()->__("Webhook delete failed. Reason: %s", $e->getMessage()), Mage_Api2_Model_Server::HTTP_INTERNAL_ERROR);
        }

        $responseBody = $this->_helper()->prepareResponseBody(self::API_RESPONSE_STATUS_SUCCESS, "", null);       
        $this->getResponse()
            ->setBody($responseBody)
            ->sendResponse();
        exit;
    }

    /**
     * Retrieve list of webhooks
     *
     * @return array
     */
    protected function _retrieveCollection()
    {
        /** @var $collection Nostress_Koongoorderapi_Model_Resource_Webhook_Collection */
        $collection = Mage::getModel('koongoorderapi/webhook')->getCollection()->load();

        $webhooksData = array();
        foreach ($collection as $key => $webhook) {
            $webhooksData[] = $this->_prepareWebhookDataForResponse($webhook);
        }

        return $webhooksData;
    }

    /**
     * Retrieve one webhook
     *
     * @return array
     */
    protected function _retrieve()
    {

        $webhookId = $this->getRequest()->getParam('id');
        $webhook = Mage::getModel('koongoorderapi/webhook')->load($webhookId);
        if(!$webhook->getId())
            $this->_critical($this->_helper()->__("Can't find webhook with id %s", $webhookId), Mage_Api2_Model_Server::HTTP_INTERNAL_ERROR);


        return $this->_prepareWebhookDataForResponse( $webhook);
    }

    /**
     * Get data validator
     *
     * @param String $operation API operation type.
     * @return Nostress_Koongoorderapi_Model_Api2_Order_Validator_Order
     */
    protected function _getDataValidator($operation)
    {
         /* @var $validator Nostress_Koongoorderapi_Model_Api2_Order_Validator_Order */
         $validator = Mage::getModel('koongoorderapi/api2_webhook_validator_webhook', array(
            'operation' => $operation
        ));
        return $validator;
    }
}
