<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * API2 webhook data validator (Koongo)
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */

class Nostress_Koongoorderapi_Model_Api2_Webhook_Validator_Webhook extends Mage_Api2_Model_Resource_Validator
{
    /**
     * 
     * @var Nostress_Koongoorderapi_Helper_Data
     */
    protected $_helper;

    /**
     * Input data updated by information from database
     */
    protected $_dataUpdated;

    public function __construct($options)
    {
        if (!isset($options['operation']) || empty($options['operation'])) {
            throw new Exception($this->_helper()->__("Passed parameter 'operation' is empty."));
        }
        $this->_operation = $options['operation'];
    }

    /**
     * Validate data
     *
     * @param array $data
     * @return bool
     */
    public function isValidData(array $data)
    {       
        $isSatisfied = true;
        try {
            
            if($this->_isUpdate() || $this->_isCreate())
            {                
                $this->_validateStoreId($data);
                $this->_validateDataItem($data, "url");
                $this->_validateDataItem($data, "secret");
                $this->_validateDataItem($data, "topic");                
            }            
        } catch (Mage_Api2_Exception $e) {
            $this->_addError($e->getMessage());
            $isSatisfied = false;
        }

        return $isSatisfied;
    }

    /**
     * Is update mode
     *
     * @return bool
     */
    protected function _isCreate()
    {
        return $this->_operation == Mage_Api2_Model_Resource::OPERATION_CREATE;
    }

    /**
     * Is update mode
     *
     * @return bool
     */
    protected function _isUpdate()
    {
        return $this->_operation == Mage_Api2_Model_Resource::OPERATION_UPDATE;
    }

    protected function _validateDataItem($data, $index)
    {
        if (!isset($data[$index]) || empty($data[$index])) {
            $this->_critical($this->_helper()->__('Missing "%s" in request.',$index), Mage_Api2_Model_Server::HTTP_BAD_REQUEST);
        }
    }
    /**
     * Validate provided store id
     *
     * @param array $data
     * @return bool
     */
    protected function _validateStoreId($data)
    {
        if (!isset($data['store_id']) || empty($data['store_id'])) {
            $this->_critical($this->_helper()->__('Missing "store_id" in request.'), Mage_Api2_Model_Server::HTTP_BAD_REQUEST);
        }
        else
        {
            /** @var $store Mage_Core_Model_Store */            
            $store = Mage::getModel('core/store')->load($data['store_id']);
            if(!$store->getId())
                $this->_critical($this->_helper()->__('Store with id %s is not available.',$data['store_id']), Mage_Api2_Model_Server::HTTP_BAD_REQUEST);
        }
    }    

    /**
     * Throw API2 exception
     *
     * @param string $message
     * @param int $code
     * @throws Mage_Api2_Exception
     */
    protected function _critical($message, $code)
    {
        throw new Mage_Api2_Exception($message, $code);
    }        
    
    protected function _helper()
    {
        if(!isset($this->_helper))
    	    $this->_helper = Mage::helper('koongoorderapi/data');
    	return $this->_helper;
    }
}
