<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * Carrier for Koongo order api module
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */
class Nostress_Koongoorderapi_Model_Carrier_Koongo extends Mage_Shipping_Model_Carrier_Abstract
    implements Mage_Shipping_Model_Carrier_Interface
{
    protected $_code = 'koongo';
 
    /**
     * Returns array of key-value pairs of all available methods
     *
     * @return Array
     */
    public function getAllowedMethods()
    {
        return array(
            $this->_code    =>  $this->getConfigData('name')            
        );
    }

    /**
     * Not active on frontend
     *
     * @return boolean
     */
    public function isActive()
    {
        return false;
    }

    /**
     * Caculate and return shipping rates
     *
     * @param Mage_Shipping_Model_Rate_Request $request
     * @return bool|false|Mage_Core_Model_Abstract|Mage_Shipping_Model_Rate_Result|null
     */
    public function collectRates(Mage_Shipping_Model_Rate_Request $request)
    {
        /** @var Mage_Shipping_Model_Rate_Result $result */
        $result = Mage::getModel('shipping/rate_result');                           

        $shippingCost = Mage::registry('koongoorderapi_shipping_cost');
        
        if(isset($shippingCost))
    	{            
            Mage::unregister('koongoorderapi_shipping_cost');
        }
        else 
            return false;                   

        $result->append($this->_getShippingMethodRate($shippingCost));
    
        return $result;
    }

    /**
     * Adjsut shipping rate
     *
     * @return void
     */
    protected function _getShippingMethodRate($shippingCost)
    {
        /** @var Mage_Shipping_Model_Rate_Result_Method $rate */
        $rate = Mage::getModel('shipping/rate_result_method');
    
        $rate->setCarrier($this->_code);
        $rate->setCarrierTitle($this->getConfigData('title'));
        $rate->setMethod($this->_code);
        $rate->setMethodTitle($this->getConfigData('name'));
        $rate->setPrice($shippingCost);
        $rate->setCost(0);
    
        return $rate;
    }
}
