<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * Koongo order - source for dropdown menu "Default shipping method"
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */

class Nostress_Koongoorderapi_Model_Config_Source_Shippingmethods
{		
    public function toOptionArray()
    {
        $carriers = $this->_getCarriersWithMethods();                
        
        foreach ($carriers as $code => $title) {            
            $options[] = array(
                'value' => $code,
                'label' => $title
                ); 
        }
        return $options;
    }
    
    /**
     * Get available carriers with methods
     *
     * @return void
     */
    protected function _getCarriersWithMethods()
	{
	    $carrierOptions = array();
        $carriers = Mage::getSingleton("shipping/config")->getAllCarriers();        
        foreach($carriers as $code => $model){            
            //$carrier = Mage::getSingleton('shipping/config')->getCarrierInstance($code);
			$carrierTitle = $model->getConfigData('title');	
            $availableMethods =  $model->getAllowedMethods();            
            foreach($availableMethods as $methodCode => $methodName)
            {
                $carrierMethodCode = $code . '_' . $methodCode;
                $title = "{$carrierTitle} - {$methodName}";
                $carrierOptions[$carrierMethodCode] = $title;
            }
        }   
        asort($carrierOptions);     
        return $carrierOptions;
    }

    public function getCarrierMethodTitle($carrierMethodCode)
    {
        $delimiterIndex = strpos($carrierMethodCode, "_");
        $carrierCode = substr($carrierMethodCode,0,$delimiterIndex);
        $methodCode = trim(substr($carrierMethodCode,$delimiterIndex), "_");
        // $methodCode = str_replace($carrierCode, "", $carrierMethodCode);
        $carrierModel = Mage::getSingleton('shipping/config')->getCarrierInstance($carrierCode);
        $carrierTitle = $carrierModel->getConfigData('title');	
        //throw new Exception($carrierTitle);
        $availableMethods =  $carrierModel->getAllowedMethods();  
        if(isset($availableMethods[$methodCode]))
        {
            $methodName = $availableMethods[$methodCode];
            $delimiterIndex = strpos($methodName, "|");
            $methodName = trim(substr($methodName, 0, $delimiterIndex));
            $title = "{$carrierTitle} - {$methodName}";
            return $title;
        }   
        return false;
    }
      
}
?>