<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * Abstract model for Koongo order api module
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */
class Nostress_Koongoorderapi_Model_Currency extends Mage_Core_Model_Abstract
{
    /**
     * Store for currency calculation
     *
     * @var Mage_Core_Model_Store
     */
    protected $_store;
    
    /**
     * Can do currency conversion
     *
     * @var boolean
     */
    protected $_canConvertCurrency = false;
    
    /**
     * Code of currency for conversion
     *
     * @var String
     */
    protected $_conversionCurrencyCode;
    
    /**
     * Currency rate for conversion
     *
     * @var String
     */
    protected $_conversionCurrencyRate;

    public function setStore($store)
    {
        $this->_store = $store;
    }

    /**
     * Initiate currency conversion 
     *
     * @param String $currencyCode
     * @return void
     */
    public function setCurrencyForConversion($currencyCode)
    {
        $this->_canConvertCurrency = $this->canConvertCurrency($currencyCode);
        
        if($this->_canConvertCurrency)
        {            
            $this->_conversionCurrencyCode = $currencyCode;
            $this->_conversionCurrencyRate = $this->getCurrencyConversionRateFromBase($currencyCode);
        }
    }

    /**
     * Convert price to store currency
     *
     * @param Float $price
     * @return void
     */
    public function convertPriceToStoreCurrency($price)
    {
        if(!$this->_canConvertCurrency)
            return $price;
        else
            return round($price / $this->_conversionCurrencyRate, 2);
    }

    /**
     * Can do currency conversion into currency given by code
     *
     * @param String $currencyCode
     * @return boolean
     */
    public function canConvertCurrency($currencyCode)
    {
        if($this->currencyEqualsBase($currencyCode))
            return false;
       
        $rate = $this->getCurrencyConversionRateFromBase($currencyCode);    
        if($rate == 0)
            return false;

        return true;
    }

    /**
     * Get currency rate for conversion from base store currency
     *
     * @param String $currencyCode Currency code
     * @return void
     */
    public function getCurrencyConversionRateFromBase($currencyCode)
    {
        if(!$this->currecnyIsAvailable($currencyCode))
            return 0;

        return (float) $this->_store->getBaseCurrency()->getRate($currencyCode);
    }

    /**
     * Is currency equal to store base currency
     *
     * @param String $currencyCode
     * @return boolean
     */
    public function currencyEqualsBase($currencyCode)
    {
        $storeCurrencyCode = $this->_store->getBaseCurrencyCode();
        if(strcmp(strtolower($storeCurrencyCode),strtolower($currencyCode)) == 0)
            return true;
        else
            return false;
    }

    /**
     * Currency is available for given store
     *
     * @param String $currencyCode currency code
     * @return void
     */
    public function currecnyIsAvailable($currencyCode)
    {
        $storeCurrencies = $this->_store->getAvailableCurrencyCodes();
        return array_search($currencyCode, $storeCurrencies) !== false;            
    }
}
