<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * Observer for Koongo order api module (Koongo)
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */
class Nostress_Koongoorderapi_Model_Observer extends Varien_Event_Observer
{
    const EVENT_SHIPMENT_CREATION = 'koongoorderapi_shipment_creation';
    const EVENT_SHIPMENT_TRACK_CREATION = 'koongoorderapi_shipment_track_creation';
    protected $_helper;
    
    protected function _helper()
    {
        if(!isset($this->_helper))
    	    $this->_helper = Mage::helper('koongoorderapi');
    	return $this->_helper;
    }

    /**
     * Adds column to sales order grid
     *
     * @param Varien_Event_Observer $observer
     * @return Nostress_Koongoorderapi_Model_Observer
     */
    public function appendColumnsToOrderGrid(Varien_Event_Observer $observer)
    {
        $block = $observer->getBlock();
        if (!isset($block)) {
            return $this;
        }

        if ($block->getType() == 'adminhtml/sales_order_grid') {

            /** @var $helper Nostress_Koongoorderapi_Helper_Order_Data  */
            $helper = Mage::helper('koongoorderapi/order_data');
            $canShowColumns = $helper->getGeneralConfig(Nostress_Koongoorderapi_Helper_Data::PARAM_SHOW_ORDER_GRID_COLUMNS);
            if(!$canShowColumns)
                return $this;

            $channelCodeOptions = $helper->getOrderAttributeOptions('koongo_channel_code', true);
            
            /* @var $block Mage_Adminhtml_Block_Sales_Order_Grid */
            $block->addColumnAfter('koongo_channel_code', array(
                'header'    => 'Channel (K)',
                'type'      => 'options',
                'index'     => 'koongo_channel_code',
                'align'     => 'center',
                'options'   => $channelCodeOptions,
                'renderer'  => 'koongoorderapi/adminhtml_orders_grid_renderer_channel',
                'width'     => '60px'
            ), 'real_order_id');            

            $marketplaceCodeOptions = $helper->getOrderAttributeOptions('koongo_marketplace_code');
            $block->addColumnAfter('koongo_marketplace_code', array(
                'header'    => 'Marketplace (K)',
                'type'      => 'options',
                'index'     => 'koongo_marketplace_code',
                'align'     => 'center',
                'options'   =>  $marketplaceCodeOptions,
                'renderer'  => 'koongoorderapi/adminhtml_orders_grid_renderer_marketplace',
                'width'     => '60px'
            ), 'koongo_channel_code');
            
            $block->addColumnAfter('koongo_channel_order_id', array(
                'header'    => 'Channel Order ID (K)',
                'type'      => 'text',
                'index'     => 'koongo_channel_order_id',
                'align'     => 'center',                                
                'width'     => '60px'
            ), 'koongo_channel_code');
        }
        return $this;
    }

    /**
     * Check if the shipment is new and should be transfared by webhook
     *
     * @param Varien_Event_Observer $observer
     * @return void
     */
    // public function orderShipmentSaveBefore(Varien_Event_Observer $observer)
    // {        
    //     $shippment = $observer->getShipment();
    //     if ($shippment->isObjectNew()) {
    //         //Shipment created from kaas by our module
    //         if (Mage::registry("koongoorderapi_shipment_create_from_kaas"))
    //             return;
            
    //         $order = Mage::getModel('sales/order')->load($shippment->getOrderId());
    //         $koongoChannelOrderId = $order->getKoongoChannelOrderId();
    //         if(isset($koongoChannelOrderId) && $koongoChannelOrderId != "")
    //         {
    //             Mage::register(self::EVENT_SHIPMENT_CREATION, true);
    //         }
    //     }
    // }
    
    /**
     * Check flag EVENT_SHIPMENT_CREATION and send shipment via webhook
     *
     * @param Varien_Event_Observer $observer
     * @return void
     */
    // public function orderShipmentSaveAfter(Varien_Event_Observer $observer)
    // {    
    //     if (Mage::registry("koongoorderapi_order_canceled_from_kaas"))
    //         return;

    //     //Webhook for shipment should not be fired
    //     if (!Mage::registry(self::EVENT_SHIPMENT_CREATION)) {            
    //         return;
    //     }
    //     Mage::unregister(self::EVENT_SHIPMENT_CREATION);
        
    //     //Fire shipment webhook
    //     $this->_addShipmentEvent($observer->getShipment());
    // }

     /**
     * Check if the track is new and should be transfared with shipment by webhook
     *
     * @param Varien_Event_Observer $observer
     * @return void
     */
    public function orderShipmentTrackSaveBefore(Varien_Event_Observer $observer)
    {        
        $event = $observer->getEvent();
        $track = $event->getTrack();

        if ($track->isObjectNew()) {
            //Shipment created from kaas by our module
            if (Mage::registry("koongoorderapi_shipment_create_from_kaas"))
                return;
            //Track added in Mage_Sales_Model_Order_Shipment_Api -> addTrack function
            if (Mage::registry("koongoorderapi_shipment_create_at_add_track"))
                return;
            
            $order = $track->getShipment()->getOrder();            
            $koongoChannelOrderId = $order->getKoongoChannelOrderId();
            if(isset($koongoChannelOrderId) && $koongoChannelOrderId != "")
            {
                Mage::register(self::EVENT_SHIPMENT_TRACK_CREATION, true);
            }
        }
    }

    /**
     * Once track is added => send shipment with tracking number
     *
     * @param Varien_Event_Observer $observer
     * @return void
     */
    public function orderShipmentTrackSaveAfter(Varien_Event_Observer $observer)
    {    
        //Webhook for shipment track should not be fired
        if (!Mage::registry(self::EVENT_SHIPMENT_TRACK_CREATION)) {            
            return;
        }
        Mage::unregister(self::EVENT_SHIPMENT_TRACK_CREATION);

        $event = $observer->getEvent();
        $track = $event->getTrack();
        
        //Fire shipment webhook
        $this->_addShipmentEvent($track->getShipment(), $track);
    }

    /**
     * Correct credit memo if is related to Koongo imported order
     *
     * @param Varien_Event_Observer $observer
     * @return void
     */
    public function orderCreditmemoSaveBefore(Varien_Event_Observer $observer)
    {
        $creditmemo = $observer->getEvent()->getCreditmemo();
        $order = $creditmemo->getOrder();
        
        $koongoChannelOrderId = $order->getKoongoChannelOrderId();
        if(isset($koongoChannelOrderId) && $koongoChannelOrderId != "")
        {
            $this->_correctCreditMemo($creditmemo, $order);

            $order->setBaseTotalOfflineRefunded($order->getBaseGrandTotal());
            $order->setBaseTotalRefunded($order->getBaseGrandTotal());
            $order->setTotalOfflineRefunded($order->getGrandTotal());
            $order->setTotalRefunded($order->getGrandTotal());
            $order->save();
        }        
    }

    /**
     * Correct credit memo according to imported order data
     *
     * @param Mage_Sales_Model_Order_Creditmemo $creditMemo
     * @param Mage_Sales_Model_Order $order
     * @return void
     */
    protected function _correctCreditMemo($creditmemo, $order)
    {
        $creditmemo->setGrandTotal($order->getGrandTotal());
        $creditmemo->setBaseGrandTotal($order->getBaseGrandTotal());
    }

    /**
     * Check if order was canceled and 
     *
     * @param Varien_Event_Observer $observer
     * @return void
     */
    public function orderSaveAfter(Varien_Event_Observer $observer)
    {
        /* @var $order Mage_Sales_Model_Order */
        $order = $observer->getEvent()->getOrder();

        $koongoChannelOrderId = $order->getKoongoChannelOrderId();
        //The order was not created by Koongo
        if(!isset($koongoChannelOrderId) || $koongoChannelOrderId == "")
            return;
        //Order cancel came from Koongo
        if (Mage::registry("koongoorderapi_order_canceled_from_kaas"))
            return;
                
        $oldStatus = $order->getOrigData('status');
        $status = $order->getStatus();

        if(($oldStatus != $status))
        {
            if($status == 'canceled')
            {
                //Fire cancel webhook
                $this->_addCancelOrderEvent($order);
            }
            else if($status == 'closed')
            {
                //Send cancel order webhook if order has no shipment
                if(!Mage::helper('koongoorderapi/order_data')->orderHasShipment($order))
                {
                    //Fire cancel webhook if order was not shipped
                   $this->_addCancelOrderEvent($order);
                }               
            }            
        }
    }    

    /**
     * Prepare cancel order events and process events
     *
     * @param Mage_Sales_Model_Order $order
     * @return void
     */
    protected function _addCancelOrderEvent($order)
    {
        $cancelReason = $this->_helper()->__("Order canceled at Magento store.");
        $eventIds = Mage::getSingleton("koongoorderapi/webhook_event_manager")->addCancelOrderEvents($order, $cancelReason);
        Mage::getSingleton("koongoorderapi/webhook_event_processor")->processWebhookEvents($eventIds);
    }

    /**
     * Prepare shipment events and process events
     *
     * @param Mage_Sales_Model_Order_Shipment $shipment
     * @param Mage_Sales_Model_Order_Shipment_Track $track
     * @return void
     */
    protected function _addShipmentEvent($shipment, $track)
    {
        $eventIds = Mage::getSingleton("koongoorderapi/webhook_event_manager")->addShipmentEvents($shipment, $track);
        Mage::getSingleton("koongoorderapi/webhook_event_processor")->processWebhookEvents($eventIds);
    }

    /**
     * Process koongo webhooks
     *
     * @param Mage_Cron_Model_Schedule $schedule
     */
    public function processWebhooks($schedule)
    {   
        Mage::getModel("koongoorderapi/webhook_event_processor")->processWebhookEvents();
    }
    
}