<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * Rewrite of Sales order shippment API
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */
class Nostress_Koongoorderapi_Model_Sales_Order_Shipment_Api extends Mage_Sales_Model_Order_Shipment_Api
{
    /**
     * Add tracking number to order
     *
     * @param string $shipmentIncrementId
     * @param string $carrier
     * @param string $title
     * @param string $trackNumber
     * @return int
     */
    public function addTrack($shipmentIncrementId, $carrier, $title, $trackNumber)
    {    
        Mage::register("koongoorderapi_shipment_create_at_add_track", true);    //prevent duplicit shipment webhook
        $trackId = parent::addTrack($shipmentIncrementId, $carrier, $title, $trackNumber);
        Mage::unregister("koongoorderapi_shipment_create_at_add_track"); 

        $shipment = Mage::getModel('sales/order_shipment')->loadByIncrementId($shipmentIncrementId);        
        $order = $shipment->getOrder();            
        $koongoChannelOrderId = $order->getKoongoChannelOrderId();
        if(isset($koongoChannelOrderId) && $koongoChannelOrderId != "")
        {
            $track = $shipment->getTrackById($trackId);
            $this->_addShipmentEvent($shipment, $track);
        }        

        return $trackId;
    }

     /**
     * Prepare shipment events and process events
     *
     * @param Mage_Sales_Model_Order_Shipment $shipment
     * @param Mage_Sales_Model_Order_Shipment_Track $track
     * @return void
     */
    protected function _addShipmentEvent($shipment, $track)
    {
        $eventIds = Mage::getSingleton("koongoorderapi/webhook_event_manager")->addShipmentEvents($shipment, $track);
        Mage::getSingleton("koongoorderapi/webhook_event_processor")->processWebhookEvents($eventIds);
    }

} // Class Nostress_Koongoorderapi_Model_Order_Shipment_Api End
