<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * Webhook event model for Koongo order api module
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */
class Nostress_Koongoorderapi_Model_Webhook_Event extends Nostress_Koongoorderapi_Model_Abstract
{
	const STATUS_PENDING = "pending";
	const STATUS_PROCESSING = "processing";
	const STATUS_FINISHED = "finished";
	const STATUS_ERROR = "error";
	const STATUS_DUPLICATED = "duplicated";
	
    public function _construct() {
		parent::_construct ();
		$this->_init ('koongoorderapi/webhook_event');
	}

	/**
	 * Update webhook event status
	 *
	 * @param string $status
	 * @param string $message
	 * @return void
	 */
	public function updateStatus($status, $message = null)
	{
		$this->setStatus($status);
		if(isset($message))
			$this->setMessage($message);
		$now = $this->_helper()->getNow();
		$this->setupdatedAt($now);
		$this->save();
	}

	/**
	 * Get available statuses
	 *
	 * @return void
	 */
	public function getStatusesAsIndexedArray()
	{
		return array(
			self::STATUS_PENDING, self::STATUS_PENDING,
			self::STATUS_PROCESSING => self::STATUS_PROCESSING,
			self::STATUS_FINISHED => self::STATUS_FINISHED,
			self::STATUS_DUPLICATED => self::STATUS_DUPLICATED,
			self::STATUS_ERROR => self::STATUS_ERROR
		);
	}

}
