<?php
/**
 * Magento Module developed by NoStress Commerce
 *
 * NOTICE OF LICENSE
 *
 * This program is licensed under the Koongo software licence (by NoStress Commerce). 
 * With the purchase, download of the software or the installation of the software 
 * in your application you accept the licence agreement. The allowed usage is outlined in the
 * Koongo software licence which can be found under https://docs.koongo.com/display/koongo/License+Conditions
 *
 * Any modification or distribution is strictly forbidden. The license
 * grants you the installation in one application. For multiuse you will need
 * to purchase further licences at https://store.koongo.com/.
 *
 * See the Koongo software licence agreement for more details.
 * @copyright Copyright (c) 2018 NoStress Commerce (http://www.nostresscommerce.cz, http://www.koongo.com/)
 *
 */

/**
 * Controller for webhook events for Koongo order api module
 *
 * @category   Koongoorderapi
 * @package    Nostress_Koongoorderapi
 * @author     NoStress Commerce
 */

class Nostress_Koongoorderapi_Adminhtml_Webhook_EventController extends Mage_Adminhtml_Controller_Action
{
	protected $_helper;
	
	/** Magento 1.9.2.0 or patch 6285_CE_1.9.1.1 access permissions fix*/
	protected function _isAllowed()
	{
		return true;
	}

	protected function helper()
	{
		if(!isset($this->_helper))
			$this->_helper = Mage::helper('koongoorderapi');
		return $this->_helper;
	}
		
    /**
     * Webhook list.
     */
    public function indexAction()
    {
    	$this->_title($this->__('Webhook Events'))->_title($this->__('Order API'));
        $this->loadLayout();
        $this->_setActiveMenu('koongoconnector/koongoorderapi_webhooks');        
        $this->renderLayout();
    }
    
	public function massDeleteAction()
    {
        $ids = $this->getRequest()->getParam('event');
        if (!is_array($ids)) {
            $this->_getSession()->addError($this->__('Please select items(s)'));
        }
        else {
            try {               
                foreach ($ids as $id)
                {
                    $event = Mage::getModel('koongoorderapi/webhook_event')->load($id);                    
                    $event->delete();                	
                }
                $this->_getSession()->addSuccess(
                    $this->__('Total of %d item(s) were successfully deleted', count($ids))
                );
            } catch (Exception $e) {
                $this->_getSession()->addError($e->getMessage());
            }
        }
        $this->_redirect('*/*/index');
    }

    /**
     * Execute events
     *
     * @return void
     */
    public function massRunAction()
    {
        $ids = $this->getRequest()->getParam('event');
        if (!is_array($ids)) {
            $this->_getSession()->addError($this->__('Please select items(s)'));
        }
        else {
            try {
                $this->_eventsUpdateStatus($ids, Nostress_Koongoorderapi_Model_Webhook_Event::STATUS_PENDING);
                Mage::getSingleton("koongoorderapi/webhook_event_processor")->processWebhookEvents($ids);

                $this->_getSession()->addSuccess(
                    $this->__('Total of %d item(s) were successfully executed', count($ids))
                );
            } catch (Exception $e) {
                $this->_getSession()->addError($e->getMessage());
            }
        }
        $this->_redirect('*/*/index');
    }

    /**
     * Adjust pending status to events
     *
     * @return void
     */
    public function massSetPendingAction()
    {
        $ids = $this->getRequest()->getParam('event');
        if (!is_array($ids)) {
            $this->_getSession()->addError($this->__('Please select items(s)'));
        }
        else {
            try {
                $this->_eventsUpdateStatus($ids, Nostress_Koongoorderapi_Model_Webhook_Event::STATUS_PENDING);                

                $this->_getSession()->addSuccess(
                    $this->__('Total of %d item(s) were successfully updated', count($ids))
                );
            } catch (Exception $e) {
                $this->_getSession()->addError($e->getMessage());
            }
        }
        $event = Mage::getModel('koongoorderapi/webhook_event')->load(80);     
        $this->_redirect('*/*/index');
    }

    /**
     * Update status at events with given Ids
     *
     * @param Array $eventIds
     * @param string $status
     * @return void
     */
    protected function _eventsUpdateStatus($eventIds, $status)
    {
        foreach ($eventIds as $id)
        {           
            $event = Mage::getModel('koongoorderapi/webhook_event')->load($id);            
            $event->updateStatus($status, "");                             
        }
    }
}